@@ -21,6 +21,7 @@
 #' @importFrom ggplot2 ggplot geom_rect aes geom_text theme_minimal labs theme
 
 mcfa.scatterplot <- function(x, y, sym.data, pos.var) {
+
   x <- to.v2(x)
   y <- to.v2(y)
   sym.data <- to.v2(sym.data)
@@ -30,10 +31,11 @@ mcfa.scatterplot <- function(x, y, sym.data, pos.var) {
     var.names <- c(var.names, sym.data[, i]$sym.var.names)
     n.vars <- c(n.vars, ncol(sym.data[, i]$data))
   }
+
   df <- cbind(x$data, y$data)
   colnames(df) <- c("C1", "C1.1", "C2", "C2.1")
   df$var.name <- purrr::flatten_chr(purrr::map2(var.names, n.vars, ~ rep(.x, .y)))
-  df$cat.name <- row.names(df)
+  df$cat.name <- x$sym.obj.names
 
   ggplot(data = df) +
     geom_rect(mapping = aes(xmin = C1, xmax = C1.1, ymin = C2, ymax = C2.1, color = var.name), fill = NA, size = 1) +
